==> ruby-web-common-0.9.7.tgz: package/src/components/price_block/index.tsx <==
// node modules
import React, { FC } from 'react';

// local components
import { SimpleButton } from "../buttons/simple_button";
import { Typography } from "../typography";

// local files
import { theming } from "../../theme";
import checkIcon from '../../assets/check_icon_black.svg';
import closeIcon from '../../assets/close_icon.svg';
import { useStyles } from "./styles";

export interface PriceBlockProps {
    btnLabel: string;
    active: boolean;
    price: string | number;
    term: string;
    savingPrice: string | number;
    trialTitle: string;
    onClick?: () => void;
    currency?: string;
}

export const PriceBlock: FC<PriceBlockProps> = ({
    btnLabel,
    active,
    price,
    term,
    savingPrice,
    trialTitle,
    currency = '$',
    onClick = () => {}
}) => {
    const {
        wrapper,
        icon,
        content,
        btn,
        activeBtn,
        activeImg,
        typClass,
        priceWrapper,
        activeTotalSavingTitle,
        priceWrapperActive,
        wrapperActive,
        activePopUp
    } = useStyles({ theme: theming.useTheme() });
    return (
        <div className={`${wrapper} ${active ? wrapperActive : ''}`}>
            <div className={content}>
                <Typography className={`${priceWrapper} ${active ? priceWrapperActive : ''}`} variant="body1">
                    {currency}{price}<Typography variant="body2">/{term}</Typography>
                </Typography>
                <Typography className={typClass} variant="h4">Total saving</Typography>
                <Typography className={active ? activeTotalSavingTitle : ''} variant="title">
                    {currency}{savingPrice}
                </Typography>
                <Typography className={typClass} variant="h4">{trialTitle}</Typography>
                <img className={`${icon} ${active ? activeImg : ''}`} src={active ? closeIcon : checkIcon} alt=""/>
                <SimpleButton onClick={onClick} className={`${btn} ${active ? activeBtn : ''}`} label={btnLabel} />
            </div>
            {active && (
                <Typography className={activePopUp} variant="label">
                    POPULAR
                </Typography>
            )}
        </div>
    )
}

==> ruby-web-common-1.5.3.tgz: package/src/components/price_block/index.tsx <==
// node modules
import React, { FC } from 'react';

// local components
import { SimpleButton } from "../buttons/simple_button";
import { Typography } from "../typography";

// local files
import { theming } from "../../theme";
import checkIcon from '../../assets/check_icon_black.svg';
import closeIcon from '../../assets/close_icon.svg';
import { useStyles } from "./styles";

export interface PriceBlockProps {
    btnLabel: string;
    active: boolean;
    price: string | number;
    term: string;
    savingPrice: string | number;
    trialTitle: string;
    onClick?: () => void;
    currency?: string;
    className?: string;
}

export const PriceBlock: FC<PriceBlockProps> = ({
    btnLabel,
    active,
    price,
    term,
    savingPrice,
    trialTitle,
    currency = '$',
    className = '',
    onClick = () => {}
}) => {
    const {
        wrapper,
        icon,
        content,
        btn,
        activeBtn,
        activeImg,
        typClass,
        priceWrapper,
        activeTotalSavingTitle,
        priceWrapperActive,
        wrapperActive,
        activePopUp
    } = useStyles({ theme: theming.useTheme() });
    return (
        <div className={`${wrapper} ${active ? wrapperActive : ''} ${className}`}>
            <div className={content}>
                <Typography className={`${priceWrapper} ${active ? priceWrapperActive : ''}`} variant="body1">
                    {currency}{price}<Typography variant="body2">/{term}</Typography>
                </Typography>
                <Typography className={typClass} variant="h4">Total saving</Typography>
                <Typography className={active ? activeTotalSavingTitle : ''} variant="title">
                    {currency}{savingPrice}
                </Typography>
                <Typography className={typClass} variant="h4">{trialTitle}</Typography>
                <img className={`${icon} ${active ? activeImg : ''}`} src={active ? closeIcon : checkIcon} alt=""/>
                <SimpleButton onClick={onClick} className={`${btn} ${active ? activeBtn : ''}`} label={btnLabel} />
            </div>
            {active && (
                <Typography className={activePopUp} variant="label">
                    POPULAR
                </Typography>
            )}
        </div>
    )
}
